function [fname,pname] = mesh_inp_Q4(Lx,Ly,Nh,EYoung,NuPoisson,loading)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Create mesh with quadrangular element (4 nodes)
%
%               ELSET=5
%          _________________
%         |                 |
% ELSET=1 |     ELSET=3     |  ELSET = 2
%         |________________ |
%   Node1      ELSET = 4
%
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
mmx=Lx*Nh;
mmy=Ly*Nh;
Nex=mmx;    % Number of element : e_x
Ney=mmy;    % Number of element : e_y
Nnx=Nex+1;
Nny=Ney+1;
Dx=Lx/Nex;
Dy=Ly/Ney;
% Creation mesh beam_Q4.msh
%==========================
pname='input/';
fid = fopen([pname,'beam_Q4.msh'],'wt');
fprintf(fid,'%s\n','$NOD');
NOD=Nnx*Nny;             % Total number of node
fprintf(fid,'%i\n',NOD);
for j=1:Nny,
    for i=1:Nnx,
        fprintf(fid,'%i %6f %6f %6f\n',i+Nnx*(j-1),Dx*(i-1),Dy*(j-1),0);
    end
end
fprintf(fid,'%s\n','$ENDNOD');
% ELSET = 3                     % Physical Surface  3
ELM3=Nex*Ney;
% ELSET = 1                     % DBC Physical Line 1
ELML1=Ney;
% ELSET = 2                     % TBC Physical Line 2
ELML2=Ney;
% ELSET = 4                     % TBC Physical Line 4
ELML4=Nex;
% ELSET = 5                     % TBC Physical Line 5
ELML5=Nex;
fprintf(fid,'%s\n','$ELM');
ELM=ELM3+ELML1+ELML2+ELML4+ELML5;
fprintf(fid,'%i\n',ELM);
ELSET=1;    % x=0
for i=1:ELML1
    fprintf(fid,'%i %i %i %i %i %i %i\n',...
        i,1,ELSET,0,2,(NOD-i*Nnx+1),(NOD-(i+1)*Nnx+1));
end
ELSET=2;    % x=Lx
for i=1:ELML2
    fprintf(fid,'%i %i %i %i %i %i %i\n',...
        ELML1+i,1,ELSET,0,2,(i*Nnx),(i+1)*Nnx);
end
ELSET=4;    % y=0
for i=1:ELML4
    fprintf(fid,'%i %i %i %i %i %i %i\n',...
        ELML1+ELML2+i,1,ELSET,0,2,i,(i+1));
end
ELSET=5;    % y=Ly
for i=1:ELML5
    fprintf(fid,'%i %i %i %i %i %i %i\n',...
        ELML1+ELML2+ELML4+i,1,ELSET,0,2,NOD-(i-1),NOD-i);
end
ELSET=3;
for j=1:Ney
    nd=(j-1)*(Nex+1);
    for i=1:Nex
        fprintf(fid,'%i %i %i %i %i %i %i %i %i\n',...
            ELML1+ELML2+ELML4+ELML5+i+(j-1)*Nex,4,ELSET,0,4,i+nd,i+1+nd,...
            i+Nnx+1+nd,i+Nnx+nd);
    end
end
fprintf(fid,'%s\n','$ENDELM');
fclose(fid);

% Creation input file beam_Q4.inp
%================================
fname='beam_Q4.inp';
fid = fopen([pname,fname],'wt');
fprintf(fid,'%s\n\n','beam_Q4.msh');
fprintf(fid,'%s\n','*ANALYSIS');
switch loading
    case 'compress'
        fprintf(fid,'%s\n','STATIC,TYPE=PLANESTRAIN');
    case {'bending_Fd','bending_Ud'}
        fprintf(fid,'%s\n','STATIC,TYPE=PLANESTRESS');
    otherwise
        fprintf(fid,'%s\n','STATIC,TYPE=PLANESTRESS');
end
integration='gauss'; % direct, gauss, gauss_reduced, gauss_selective,gauss_selective_incompress
switch integration
    case 'direct'
        fprintf(fid,'%s\n','INTEGRATION=DIRECT');
    case 'gauss'
        fprintf(fid,'%s\n','INTEGRATION=GAUSS');
    case 'gauss_reduced'
        fprintf(fid,'%s\n','INTEGRATION=GAUSS_REDUCED');
    case 'gauss_selective'
        fprintf(fid,'%s\n','INTEGRATION=GAUSS_SELECTIVE');
    case 'gauss_selective_incompress'
        fprintf(fid,'%s\n','INTEGRATION=GAUSS_SELECTIVE_INCOMPRESS');
end

fprintf(fid,'%s\n\n','**');

fprintf(fid,'%s\n','*MATERIAL,TYPE=ISOTROPIC');
fprintf(fid,'%s%f\n','YOUNG=',EYoung);
fprintf(fid,'%s%f\n','POISSON=',NuPoisson);
fprintf(fid,'%s\n\n','**');

fprintf(fid,'%s\n','*SOLID');
fprintf(fid,'%s\n','ELSET=3');
fprintf(fid,'%s\n\n','**');

switch loading
    case 'compress'
        Ud=-0.1;
        fprintf(fid,'%s\n','*DBC');
        fprintf(fid,'%s\n','ELSET=1,DIR=1,VAL=0.');
        fprintf(fid,'%s\n','NODE=1,DIR=2,VAL=0.');
        fprintf(fid,'%s\n','ELSET=4,DIR=2,VAL=0.');
        fprintf(fid,'%s%f\n','ELSET=2,DIR=1,VAL=',Ud);
        fprintf(fid,'%s\n','ELSET=2,DIR=2,VAL=0.');
        fprintf(fid,'%s\n\n','**');
    case 'bending_Fd'
        Fd=0.01;
        fprintf(fid,'%s\n','*DBC');
        fprintf(fid,'%s\n','ELSET=1,DIR=1,VAL=0.');
        fprintf(fid,'%s\n','NODE=1,DIR=2,VAL=0.');
        fprintf(fid,'%s\n\n','**');
        fprintf(fid,'%s\n','*TBC');
        fprintf(fid,'%s%f\n','ELSET=2,DIR=2,VAL=',Fd);
        fprintf(fid,'%s\n\n','**');
    case 'bending_Ud'
        Ud=1;
        fprintf(fid,'%s\n','*DBC');
        fprintf(fid,'%s\n','ELSET=1,DIR=1,VAL=0.');
        fprintf(fid,'%s\n','NODE=1,DIR=2,VAL=0.');
        fprintf(fid,'%s%f\n','ELSET=2,DIR=2,VAL=',Ud);
        fprintf(fid,'%s\n\n','**');
    otherwise
        disp('Unknown loading type')
end

fprintf(fid,'%s\n\n','*ENDFILE');
fclose(fid);
